@@ -108,14 +108,6 @@ test_that("multiple tables work", {
 test_that("all current tables work", {
   skip_if_offline()
   skip_on_cran()
-  # skip_on_ci()
-
-  rba_site_works <- ifelse(is.null(curl::nslookup("rba.gov.au", error = FALSE)),
-    FALSE,
-    TRUE
-  )
-
-  skip_if(isFALSE(rba_site_works))
 
   tab <- table_list %>%
     dplyr::filter(current_or_historical == "current" &
@@ -123,6 +115,7 @@ test_that("all current tables work", {
 
   for (tab in tab$no) {
     Sys.sleep(1)
+    print(tab)
     df <- read_rba(table_no = tab, cur_hist = "current")
     expect_true(check_df(df))
   }
@@ -139,6 +132,7 @@ test_that("historical tables work", {
 
   for (tab in tab$no) {
     df <- read_rba(table_no = tab, cur_hist = "historical")
+    print(tab)
     expect_true(check_df(df))
     Sys.sleep(1)
   }
